import { IConstruct } from 'constructs';
import { BoundGroupConfiguration, IGroupConfiguration } from './configuration-ref';
/**
 * Configuration options for configuring a Resource Group containing resources
 * based on a set of matching tags.
 */
export declare class TagFilterProps {
    /**
     * The resource types that are allowed to be in the Resource Group being
     * configured.
     */
    readonly resourceTypes?: string[];
    /**
     * The filters that should be used to determine the resources that belong to
     * the resource group.
     */
    readonly tagFilters?: {
        [key: string]: string[];
    };
}
export declare class TagFilter implements IGroupConfiguration {
    /**
     * Internal collection of resource types that are allowed to be in the
     * Resource Group being configured.
     */
    private readonly _resourceTypes;
    /**
     * Internal collection of filters to be used to determine the resources that
     * belong to the Resource Group.
     */
    private readonly _tagFilters;
    /**
     * Collection of resource types that are allowed to be in the Resource Group
     * being configured.
     */
    get resourceTypes(): string[];
    /**
     * Collection of filters to be used to determine the resources that belong to
     * the Resource Group.
     */
    get tagFilters(): {
        [key: string]: string[];
    };
    /**
     * Creates a new instance of the TagFilter class.
     *
     * @param props Settings to use when applying the tag filter.
     */
    constructor(props?: TagFilterProps);
    /**
     * Add a resource type to the resource group.
     *
     * If no resource types are registered in the configuration then all resource
     * types are allowed.
     *
     * @param typeId The type that is to be added to the resource group.
     * @returns The Resource Group configuration object to which the type was
     * registered.
     */
    addResourceType(typeId: string): TagFilter;
    /**
     * Adds a new tag filter that should be used for controlling the resources in
     * the Resource Group.
     *
     * @param key The name of the tag to be filtered on.
     * @param values Values to match for the given tag.
     * @returns The Resource Group configuration object to which the type was
     * registered.
     */
    addTagFilter(key: string, ...values: string[]): TagFilter;
    /**
     * Associates this configuration with a construct that is handling the
     * creation of a resource group.
     *
     * @param _scope The construct managing the creation of the Resource Group.
     * @returns The configuration to be used for the Resource Group.
     */
    bind(_scope: IConstruct): BoundGroupConfiguration;
}
